@@ -19,14 +19,14 @@
 
 /* expansion generator state */
 typedef struct Expand {
-	/* int  type; */	/* see expand() */
+	/* int type; */		/* see expand() */
 	const char *str;	/* string */
 	union {
 		const char **strv;/* string[] */
-		struct shf *shf;/* file */
+		struct shf *shf;  /* file */
 	} u;			/* source */
 	struct tbl *var;	/* variable in ${var..} */
-	short	split;		/* split "$@" / call waitlast $() */
+	short split;		/* split "$@" / call waitlast $() */
 } Expand;
 
 #define	XBASE		0	/* scanning original */
@@ -41,25 +41,21 @@ typedef struct Expand {
 #define IFS_WS		1	/* have seen IFS white-space */
 #define IFS_NWS		2	/* have seen IFS non-white-space */
 
-static	int	varsub ARGS((Expand *xp, char *sp, char *word, int *stypep, int *slenp));
-static	int	comsub ARGS((Expand *xp, char *cp));
-static	char   *trimsub ARGS((char *str, char *pat, int how));
-static	void	tmpglob ARGS((char *cp, XPtrV *wp, int markdirs));
+static int varsub(Expand *, const char *, const char *, int *, int *);
+static int comsub(Expand *, const char *);
+static char *trimsub(char *, char *, int);
+static void tmpglob(char *, XPtrV *, int);
 static void globit(XString *, char **, char *, XPtrV *, int);
-static char	*maybe_expand_tilde ARGS((char *p, XString *dsp, char **dpp,
-					  int isassign));
-static	char   *tilde ARGS((char *acp));
-static	char   *homedir ARGS((char *name));
+static const char *maybe_expand_tilde(const char *, XString *, char **, int);
+static char *tilde(char *);
+static char *homedir(char *);
 #ifdef BRACE_EXPAND
-static void	alt_expand ARGS((XPtrV *wp, char *start, char *exp_start,
-				 char *end, int fdo));
+static void alt_expand(XPtrV *, char *, char *, char *, int));
 #endif
 
 /* compile and expand word */
 char *
-substitute(cp, f)
-	const char *cp;
-	int f;
+substitute(const char *cp, int f)
 {
 	struct source *s, *sold;
 
@@ -78,12 +74,16 @@ substitute(cp, f)
  * expand arg-list
  */
 char **
-eval(char **ap, int f)
+eval(const char **ap, int f)
 {
 	XPtrV w;
 
-	if (*ap == NULL)
-		return ap;
+	if (*ap == NULL) {
+		union mksh_ccphack vap;
+
+		vap.ro = ap;
+		return (vap.rw);
+	}
 	XPinit(w, 32);
 	XPput(w, NULL);		/* space for shell name */
 #ifdef	SHARPBANG
@@ -103,17 +103,17 @@ eval(char **ap, int f)
  * expand string
  */
 char *
-evalstr(cp, f)
-	char *cp;
-	int f;
+evalstr(const char *cp, int f)
 {
 	XPtrV w;
+	char *dp = null;
 
 	XPinit(w, 1);
 	expand(cp, &w, f);
-	cp = (XPsize(w) == 0) ? null : (char*) *XPptrv(w);
+	if (XPsize(w))
+		dp = *XPptrv(w);
 	XPfree(w);
-	return cp;
+	return (dp);
 }
 
 /*
@@ -121,25 +121,26 @@ evalstr(cp, f)
  * used from iosetup to expand redirection files
  */
 char *
-evalonestr(char *cp, int f)
+evalonestr(const char *cp, int f)
 {
 	XPtrV w;
+	char *rv;
 
 	XPinit(w, 1);
 	expand(cp, &w, f);
 	switch (XPsize(w)) {
 	case 0:
-		cp = null;
+		rv = null;
 		break;
 	case 1:
-		cp = (char*) *XPptrv(w);
+		rv = (char *) *XPptrv(w);
 		break;
 	default:
-		cp = evalstr(cp, f&~DOGLOB);
+		rv = evalstr(cp, f&~DOGLOB);
 		break;
 	}
 	XPfree(w);
-	return cp;
+	return (rv);
 }
 
 /* for nested substitution: ${var:=$var2} */
@@ -162,10 +163,13 @@ expand(const char *cp,	/* input word */
 	int type;	/* expansion type */
 	int quote = 0;	/* quoted */
 	XString ds;		/* destination string */
-	char *dp, *sp;	/* dest., source */
+	char *dp;		/* destination */
+	const char *sp;		/* source */
 	int fdo, word;		/* second pass flags; have word */
-	int doblank;		/* field spliting of parameter/command subst */
-	Expand x;		/* expansion variables */
+	int doblank;		/* field splitting of parameter/command subst */
+	Expand x = {		/* expansion variables */
+		NULL, { NULL }, NULL, 0
+	};
 	SubType st_head, *st;
 	int UNINITIALIZED(newlines); /* For trailing newlines in COMSUB */
 	int saw_eq, tilde_ok;
@@ -644,12 +648,13 @@ expand(const char *cp,	/* input word */
 					    && (f & (DOTILDE|DOASNTILDE))
 					    && (tilde_ok & 2))
 					{
-						char *p, *dp_x;
+						const char *p;
+						char *dp_x;
 
 						dp_x = dp;
 						p = maybe_expand_tilde(sp,
-							&ds, &dp_x,
-							f & DOASNTILDE);
+						    &ds, &dp_x,
+						    f & DOASNTILDE);
 						if (p) {
 							if (dp != dp_x)
 								word = IFS_WORD;
@@ -683,8 +688,8 @@ expand(const char *cp,	/* input word */
 static int
 varsub(xp, sp, word, stypep, slenp)
 	Expand *xp;
-	char *sp;
-	char *word;
+	const char *sp;
+	const char *word;
 	int *stypep;	/* becomes qualifier type */
 	int *slenp;	/* " " len (=, :=, etc.) valid iff *stypep != 0 */
 {
@@ -692,7 +697,8 @@ varsub(xp, sp, word, stypep, slenp)
 	int state;	/* next state: XBASE, XARG, XSUB, XNULLSUB */
 	int stype;	/* substitution type */
 	int slen;
-	char *p, q[20];
+	const char *p;
+	char q[20];
 	struct tbl *vp;
 
 	if (sp[0] == '\0')	/* Bad variable name */
@@ -834,7 +840,7 @@ varsub(xp, sp, word, stypep, slenp)
  * Run the command in $(...) and read its output.
  */
 static int
-comsub(Expand *xp, char *cp)
+comsub(Expand *xp, const char *cp)
 {
 	Source *s, *sold;
 	struct op *t;
@@ -1111,16 +1117,13 @@ debunk(char *dp, const char *sp, size_t dlen)
  * puts the expanded version in *dcp,dp and returns a pointer in p just
  * past the name, otherwise returns 0.
  */
-static char *
-maybe_expand_tilde(p, dsp, dpp, isassign)
-	char *p;
-	XString *dsp;
-	char **dpp;
-	int isassign;
+static const char *
+maybe_expand_tilde(const char *p, XString *dsp, char **dpp, int isassign)
 {
 	XString ts;
 	char *dp = *dpp;
-	char *tp, *r;
+	char *tp;
+	const char *r;
 
 	Xinit(ts, tp, 16, ATEMP);
 	/* : only for DOASNTILDE form */
