@@ -107,7 +107,7 @@ execute(t, flags)
 		/* POSIX says expand command words first, then redirections,
 		 * and assignments last..
 		 */
-		ap = eval(t->args, t->evalflags | DOBLANK | DOGLOB | DOTILDE);
+		ap = eval((const char **)t->args, t->evalflags | DOBLANK | DOGLOB | DOTILDE);
 #ifdef SILLY_FEATURES
 		if (flags & XTIME)
 			/* Allow option parsing (bizarre, but POSIX) */
@@ -199,11 +199,8 @@ execute(t, flags)
 #ifdef KSH
 	  case TCOPROC:
 	  {
-# ifdef JOB_SIGS
 		sigset_t	omask;
-# endif /* JOB_SIGS */
 
-# ifdef JOB_SIGS
 		/* Block sigchild as we are using things changed in the
 		 * signal handler
 		 */
@@ -216,7 +213,6 @@ execute(t, flags)
 			unwind(i);
 			/*NOTREACHED*/
 		}
-# endif /* JOB_SIGS */
 		/* Already have a (live) co-process? */
 		if (coproc.job && coproc.write >= 0)
 			errorf("coprocess already exists");
@@ -245,10 +241,8 @@ execute(t, flags)
 			/* create new coprocess id */
 			++coproc.id;
 		}
-# ifdef JOB_SIGS
 		sigprocmask(SIG_SETMASK, &omask, (sigset_t *) 0);
 		e->type = E_EXEC; /* no more need for error handler */
-# endif /* JOB_SIGS */
 
 		/* exchild() closes coproc.* in child after fork,
 		 * will also increment coproc.njobs when the
@@ -307,7 +301,7 @@ execute(t, flags)
 		volatile bool_t is_first = TRUE;
 #endif /* KSH */
 		ap = (t->vars != NULL) ?
-			  eval(t->vars, DOBLANK|DOGLOB|DOTILDE)
+			  eval((const char **)t->vars, DOBLANK|DOGLOB|DOTILDE)
 			: e->loc->argv + 1;
 		e->type = E_LOOP;
 		while (1) {
