@@ -37,10 +37,6 @@ static const char *const initcoms [] = {
 	 /* Standard ksh aliases */
 	  "hash=alias -t",	/* not "alias -t --": hash -r needs to work */
 #endif /* SILLY_FEATURES */
-#ifdef JOBS
-	  "stop=kill -STOP",
-	  "suspend=kill -STOP $$",
-#endif
 #ifdef KSH
 	  "autoload=typeset -fu",
 	  "functions=typeset -f",
