@@ -46,9 +46,7 @@ initctypes()
 }
 
 char *
-str_save(s, ap)
-	register const char *s;
-	Area *ap;
+str_save(const char *s, Area *ap)
 {
 	return s ? strcpy((char*) alloc((size_t)strlen(s)+1, ap), s) : NULL;
 }
@@ -71,12 +69,9 @@ str_nsave(const char *s, int n, Area *ap)
 
 /* called from expand.h:XcheckN() to grow buffer */
 char *
-Xcheck_grow_(xsp, xp, more)
-	XString *xsp;
-	char *xp;
-	int more;
+Xcheck_grow_(XString *xsp, const char *xp, unsigned more)
 {
-	char *old_beg = xsp->beg;
+	const char *old_beg = xsp->beg;
 
 	xsp->len += more > xsp->len ? more : xsp->len;
 	xsp->beg = aresize(xsp->beg, xsp->len + 8, xsp->areap);
