@@ -174,6 +174,10 @@ int posh_builtin_cd(int argc, char **argv, int UNUSED(flags))
 		else
 #endif /* S_ISLNK */
 		{
+#ifndef CD_BREAKAGE
+			simplify_path(Xstring(xs, xp));
+			rval = chdir(try = Xstring(xs, xp));
+#else
 			char *simplified;
 
 			simplified = canonicalize_file_name(Xstring(xs, xp));
@@ -183,7 +187,7 @@ int posh_builtin_cd(int argc, char **argv, int UNUSED(flags))
 			}
 			else
 				rval = -1;
-
+#endif
 		}
 	} while (rval < 0 && cdpath != (char *) 0);
 
@@ -596,22 +600,27 @@ int posh_builtin_exportreadonlyset(int argc, char **argv, int flags)
 
 int posh_builtin_local(int argc, char **argv, int UNUSED(flags))
 {
-char *p;
+	int i;
+	char *p;
 
 	if(!argv[1])
 		return 1;
 
-        for (p = argv[1]; *p; p++) {
-		if (!isalnum(*p) && (*p!='_')) {
-			bi_errorf("%s: not identifier", argv[1]);
+	for (i = 1; i < argc; i++) {
+		for (p = argv[i]; *p; p++) {
+			if (!isalnum(*p) && (*p!='_')) {
+				bi_errorf("%s: not identifier", argv[i]);
+				return 1;
+			}
+		}
+
+		if(!local(argv[i], 0)) {
+			bi_errorf("%s: error making local", argv[i]);
 			return 1;
 		}
 	}
 
-	if(!local(argv[1], 0)) {
-		bi_errorf("%s: error making local", argv[1]);
-		return 1;
-	}
+	return 0;
 }
 
 int posh_builtin_eval(int argc, char **argv, int UNUSED(flags))
@@ -1348,7 +1357,7 @@ const struct builtin shbuiltins [] = {
  	{"export", posh_builtin_exportreadonlyset, POSH_BUILTIN_POSIX_SPECIAL | POSH_BUILTIN_KEEPASN | POSH_BUILTIN_EXPORT},
 	{"getopts", posh_builtin_getopts, POSH_BUILTIN_POSIX_REGULAR},
 	{"kill", posh_builtin_kill, POSH_BUILTIN_POSIX_REGULAR},
-	{"local", posh_builtin_local, POSH_BUILTIN_POSIX_SPECIAL | POSH_BUILTIN_KEEPASN},
+	{"local", posh_builtin_local, POSH_BUILTIN_KEEPASN},
 	{"pwd", posh_builtin_pwd, 0},
  	{"readonly", posh_builtin_exportreadonlyset, POSH_BUILTIN_POSIX_SPECIAL | POSH_BUILTIN_KEEPASN | POSH_BUILTIN_READONLY},
 	{NULL, NULL, 0}
