@@ -677,7 +677,7 @@ initkeywords()
 	transitional_tinit(&keywords, APERM); /* must be 2^n (currently 20 keywords) */
 	for (tt = tokentab; tt->name; tt++) {
 		if (tt->reserved) {
-			p = transitional_tenter(&keywords.root, tt->name);
+			p = transitional_tenter(&keywords.root, tt->name, APERM);
 			p->flag |= DEFINED|ISSET;
 			p->type = CKEYWD;
 			p->val.i = tt->val;
